Struct rustutils_factor::Factor
source · [−]pub struct Factor { /* private fields */ }Expand description
Print the prime factors of each specified integer number.
Implementations
sourceimpl Factor
impl Factor
pub fn run(&self) -> Result<(), Box<dyn Error>>
sourcepub fn handle(
&self,
callback: impl FnMut(u64, &[u64])
) -> Result<(), Box<dyn Error>>
pub fn handle(
&self,
callback: impl FnMut(u64, &[u64])
) -> Result<(), Box<dyn Error>>
Handle either the supplied numbers, or read from standard input if no numbers were supplied.
sourcepub fn handle_numbers(&self, callback: impl FnMut(u64, &[u64]))
pub fn handle_numbers(&self, callback: impl FnMut(u64, &[u64]))
Perform factorisation on the numbers supplied as arguments.
sourcepub fn handle_stdin(
&self,
callback: impl FnMut(u64, &[u64])
) -> Result<(), StdinError>
pub fn handle_stdin(
&self,
callback: impl FnMut(u64, &[u64])
) -> Result<(), StdinError>
Read lines from standard input, parse them as numbers, and perform factorisation on them.